@@ -27,11 +27,14 @@
 
 #include <glib-object.h>
 #include <gst/gstminiobject.h>
+#include <gst/gstobject.h>
 
 G_BEGIN_DECLS
 
-GST_EXPORT GType _gst_memory_type;
+GST_API GType _gst_memory_type;
 #define GST_TYPE_MEMORY (_gst_memory_type)
+
+GST_API
 GType gst_memory_get_type(void);
 
 typedef struct _GstMemory GstMemory;
@@ -47,8 +50,8 @@ typedef struct _GstAllocator GstAllocator;
  * made when this memory needs to be shared between buffers.
  * @GST_MEMORY_FLAG_ZERO_PREFIXED: the memory prefix is filled with 0 bytes
  * @GST_MEMORY_FLAG_ZERO_PADDED: the memory padding is filled with 0 bytes
- * @GST_MEMORY_FLAG_PHYSICALLY_CONTIGUOUS: the memory is physically contiguous. (Since 1.2)
- * @GST_MEMORY_FLAG_NOT_MAPPABLE: the memory can't be mapped via gst_memory_map() without any preconditions. (Since 1.2)
+ * @GST_MEMORY_FLAG_PHYSICALLY_CONTIGUOUS: the memory is physically contiguous. (Since: 1.2)
+ * @GST_MEMORY_FLAG_NOT_MAPPABLE: the memory can't be mapped via gst_memory_map() without any preconditions. (Since: 1.2)
  * @GST_MEMORY_FLAG_LAST: first flag that can be used for custom purposes
  *
  * Flags for wrapped memory.
@@ -178,11 +181,11 @@ typedef enum {
 } GstMapFlags;
 
 /**
- * GST_MAP_READWRITE:
+ * GST_MAP_READWRITE: (value 3) (type GstMapFlags)
  *
  * GstMapFlags value alias for GST_MAP_READ | GST_MAP_WRITE
  */
-#define GST_MAP_READWRITE      (GST_MAP_READ | GST_MAP_WRITE)
+#define GST_MAP_READWRITE      ((GstMapFlags) (GST_MAP_READ | GST_MAP_WRITE))
 
 
 /**
@@ -252,7 +255,7 @@ typedef gpointer    (*GstMemoryMapFullFunction)       (GstMemory *mem, GstMapInf
  * GstMemoryUnmapFunction:
  * @mem: a #GstMemory
  *
- * Return the pointer previously retrieved with gst_memory_map().
+ * Release the pointer previously retrieved with gst_memory_map().
  */
 typedef void        (*GstMemoryUnmapFunction)     (GstMemory *mem);
 
@@ -261,7 +264,7 @@ typedef void        (*GstMemoryUnmapFunction)     (GstMemory *mem);
  * @mem: a #GstMemory
  * @info: a #GstMapInfo
  *
- * Return the pointer previously retrieved with gst_memory_map() with @info.
+ * Release the pointer previously retrieved with gst_memory_map() with @info.
  */
 typedef void        (*GstMemoryUnmapFullFunction)     (GstMemory *mem, GstMapInfo * info);
 
@@ -307,42 +310,41 @@ typedef GstMemory * (*GstMemoryShareFunction)     (GstMemory *mem, gssize offset
  */
 typedef gboolean    (*GstMemoryIsSpanFunction)    (GstMemory *mem1, GstMemory *mem2, gsize *offset);
 
+GST_API
 void           gst_memory_init         (GstMemory *mem, GstMemoryFlags flags,
                                         GstAllocator *allocator, GstMemory *parent,
                                         gsize maxsize, gsize align,
                                         gsize offset, gsize size);
-
+GST_API
 gboolean       gst_memory_is_type      (GstMemory *mem, const gchar *mem_type);
 
+#ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 /* refcounting */
-/**
- * gst_memory_ref:
- * @memory: The memory to refcount
- *
- * Increase the refcount of this memory.
- *
- * Returns: (transfer full): @memory (for convenience when doing assignments)
- */
 static inline GstMemory *
 gst_memory_ref (GstMemory * memory)
 {
   return (GstMemory *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (memory));
 }
 
-/**
- * gst_memory_unref:
- * @memory: (transfer full): the memory to refcount
- *
- * Decrease the refcount of an memory, freeing it if the refcount reaches 0.
- */
 static inline void
 gst_memory_unref (GstMemory * memory)
 {
   gst_mini_object_unref (GST_MINI_OBJECT_CAST (memory));
 }
+#else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+GST_API
+GstMemory *    gst_memory_ref   (GstMemory * memory);
+
+GST_API
+void           gst_memory_unref (GstMemory * memory);
+#endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 
 /* getting/setting memory properties */
+
+GST_API
 gsize          gst_memory_get_sizes    (GstMemory *mem, gsize *offset, gsize *maxsize);
+
+GST_API
 void           gst_memory_resize       (GstMemory *mem, gssize offset, gsize size);
 
 #define        gst_memory_lock(m,f)        gst_mini_object_lock (GST_MINI_OBJECT_CAST (m), (f))
@@ -351,24 +353,32 @@ void           gst_memory_resize       (GstMemory *mem, gssize offset, gsize siz
 #define        gst_memory_make_writable(m) GST_MEMORY_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (m)))
 
 /* retrieving data */
+
+GST_API
 GstMemory *    gst_memory_make_mapped  (GstMemory *mem, GstMapInfo *info, GstMapFlags flags) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
 gboolean       gst_memory_map          (GstMemory *mem, GstMapInfo *info, GstMapFlags flags);
+
+GST_API
 void           gst_memory_unmap        (GstMemory *mem, GstMapInfo *info);
 
 /* copy and subregions */
+
+GST_API
 GstMemory *    gst_memory_copy         (GstMemory *mem, gssize offset, gssize size) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
 GstMemory *    gst_memory_share        (GstMemory *mem, gssize offset, gssize size) G_GNUC_WARN_UNUSED_RESULT;
 
 /* span memory */
+
+GST_API
 gboolean       gst_memory_is_span      (GstMemory *mem1, GstMemory *mem2, gsize *offset);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstMemory, gst_memory_unref)
-#endif
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstAllocator, gst_object_unref)
-#endif
 
 G_END_DECLS
 
